@@ -71,7 +71,19 @@ known_dns['ver']['test']['fwd']['testrvl5.example.com'] = ['1.2.1.5', 'A']
 
 
 class OptionsObject(object):
-    pass
+    """
+    object to mock optparse return object
+    """
+
+    def __init__(self):
+        """
+        preseed with default values
+        """
+        self.verify = False
+        self.config_file = None
+        self.testfile = None
+        self.ignorettl = False
+        self.sleep = None
 
 
 class TestDNSTestMain:
@@ -95,6 +107,7 @@ class TestDNSTestMain:
         config.server_prod = "prod"
         config.default_domain = ".example.com"
         config.have_reverse_dns = True
+        config.ignore_ttl = False
 
         parser = DnstestParser()
         pydnstest.parser = parser
@@ -118,6 +131,7 @@ class TestDNSTestMain:
         config.server_prod = "prod"
         config.default_domain = ".example.com"
         config.have_reverse_dns = True
+        config.ignore_ttl = False
 
         parser = DnstestParser()
         pydnstest.parser = parser
@@ -254,9 +268,7 @@ class TestDNSTestMain:
         Test calling main() with a specified config file
         """
         opt = OptionsObject()
-        setattr(opt, "verify", False)
         setattr(opt, "config_file", "dnstest.foo")
-        setattr(opt, "testfile", False)
         pydnstest.main.sys.stdin = ["foo bar baz"]
         foo = pydnstest.main.main(opt)
         out, err = capfd.readouterr()
@@ -269,14 +281,11 @@ class TestDNSTestMain:
         Test calling main() with a discovered config file
         """
         opt = OptionsObject()
-        setattr(opt, "verify", False)
-        setattr(opt, "config_file", False)
-        setattr(opt, "testfile", False)
 
         # write out an example config file
         # this will be cleaned up by restore_user_config()
         fpath = os.path.abspath("dnstest.ini")
-        self.write_conf_file(fpath, "[servers]\nprod: 1.2.3.4\ntest: 1.2.3.5\n[defaults]\nhave_reverse_dns: True\ndomain: .example.com\n")
+        self.write_conf_file(fpath, "[servers]\nprod: 1.2.3.4\ntest: 1.2.3.5\n[defaults]\nhave_reverse_dns: True\ndomain: .example.com\nignore_ttl: False\n")
 
         pydnstest.main.sys.stdin = ["foo bar baz"]
         foo = None
@@ -292,9 +301,6 @@ class TestDNSTestMain:
         Test calling main() with a specified config file
         """
         opt = OptionsObject()
-        setattr(opt, "verify", False)
-        setattr(opt, "config_file", False)
-        setattr(opt, "testfile", False)
 
         pydnstest.main.sys.stdin = ["foo bar baz"]
         foo = None
@@ -312,14 +318,12 @@ class TestDNSTestMain:
         Test with a testfile specified by not existant.
         """
         opt = OptionsObject()
-        setattr(opt, "verify", False)
-        setattr(opt, "config_file", False)
         setattr(opt, "testfile", 'nofilehere')
 
         # write out an example config file
         # this will be cleaned up by restore_user_config()
         fpath = os.path.abspath("dnstest.ini")
-        self.write_conf_file(fpath, "[servers]\nprod: 1.2.3.4\ntest: 1.2.3.5\n[defaults]\nhave_reverse_dns: True\ndomain: .example.com\n")
+        self.write_conf_file(fpath, "[servers]\nprod: 1.2.3.4\ntest: 1.2.3.5\n[defaults]\nhave_reverse_dns: True\ndomain: .example.com\nignore_ttl: False\n")
 
         foo = None
 
@@ -340,14 +344,12 @@ class TestDNSTestMain:
         monkeypatch.setattr(pydnstest.main, "run_check_line", mockreturn)
 
         opt = OptionsObject()
-        setattr(opt, "verify", False)
-        setattr(opt, "config_file", False)
         setattr(opt, "testfile", 'testfile.txt')
 
         # write out an example config file
         # this will be cleaned up by restore_user_config()
         fpath = os.path.abspath("dnstest.ini")
-        self.write_conf_file(fpath, "[servers]\nprod: 1.2.3.4\ntest: 1.2.3.5\n[defaults]\nhave_reverse_dns: True\ndomain: .example.com\n")
+        self.write_conf_file(fpath, "[servers]\nprod: 1.2.3.4\ntest: 1.2.3.5\n[defaults]\nhave_reverse_dns: True\ndomain: .example.com\nignore_ttl: False\n")
 
         foo = pydnstest.main.main(opt)
         out, err = capfd.readouterr()
@@ -367,13 +369,64 @@ class TestDNSTestMain:
 
         opt = OptionsObject()
         setattr(opt, "verify", True)
-        setattr(opt, "config_file", False)
         setattr(opt, "testfile", 'testfile.txt')
 
         # write out an example config file
         # this will be cleaned up by restore_user_config()
         fpath = os.path.abspath("dnstest.ini")
-        self.write_conf_file(fpath, "[servers]\nprod: 1.2.3.4\ntest: 1.2.3.5\n[defaults]\nhave_reverse_dns: True\ndomain: .example.com\n")
+        self.write_conf_file(fpath, "[servers]\nprod: 1.2.3.4\ntest: 1.2.3.5\n[defaults]\nhave_reverse_dns: True\ndomain: .example.com\nignore_ttl: False\n")
+
+        foo = pydnstest.main.main(opt)
+        out, err = capfd.readouterr()
+        assert foo == None
+        assert out == "OK: foobarbaz\n**NG: foofail\n++++ 1 passed / 1 FAILED. (pydnstest %s)\n" % pydnstest_version
+        assert err == ""
+
+    def test_verify_with_sleep(self, write_testfile, save_user_config, capfd, monkeypatch):
+        """
+        Test with a testfile.
+        """
+        def mockreturn(foo, bar, baz):
+            if foo == "confirm bar.jasonantman.com":
+                return {'result': False, 'message': 'foofail', 'secondary': [], 'warnings': []}
+            return {'result': True, 'message': 'foobarbaz', 'secondary': [], 'warnings': []}
+        monkeypatch.setattr(pydnstest.main, "run_verify_line", mockreturn)
+
+        opt = OptionsObject()
+        setattr(opt, "verify", True)
+        setattr(opt, "testfile", 'testfile.txt')
+        setattr(opt, "sleep", 0.001)
+
+        # write out an example config file
+        # this will be cleaned up by restore_user_config()
+        fpath = os.path.abspath("dnstest.ini")
+        self.write_conf_file(fpath, "[servers]\nprod: 1.2.3.4\ntest: 1.2.3.5\n[defaults]\nhave_reverse_dns: True\ndomain: .example.com\nignore_ttl: False\n")
+
+        foo = pydnstest.main.main(opt)
+        out, err = capfd.readouterr()
+        assert foo == None
+        assert out == "Note - will sleep 0.001 seconds between lines\nOK: foobarbaz\n**NG: foofail\n++++ 1 passed / 1 FAILED. (pydnstest %s)\n" % pydnstest_version
+        assert err == ""
+
+    def test_verify_with_ignorettl(self, write_testfile, save_user_config, capfd, monkeypatch):
+        """
+        Test with a testfile.
+        """
+        def mockreturn(foo, bar, baz):
+            if foo == "confirm bar.jasonantman.com":
+                return {'result': False, 'message': 'foofail', 'secondary': [], 'warnings': []}
+            return {'result': True, 'message': 'foobarbaz', 'secondary': [], 'warnings': []}
+        monkeypatch.setattr(pydnstest.main, "run_verify_line", mockreturn)
+
+        opt = OptionsObject()
+        setattr(opt, "verify", True)
+        setattr(opt, "testfile", 'testfile.txt')
+        setattr(opt, "ignorettl", True)
+
+        # write out an example config file
+        # this will be cleaned up by restore_user_config()
+        fpath = os.path.abspath("dnstest.ini")
+        self.write_conf_file(fpath, "[servers]\nprod: 1.2.3.4\ntest: 1.2.3.5\n[defaults]\nhave_reverse_dns: True\ndomain: .example.com\nignore_ttl: False\n")
 
         foo = pydnstest.main.main(opt)
         out, err = capfd.readouterr()
@@ -389,6 +442,34 @@ class TestDNSTestMain:
             assert options.verify == True
             assert options.config_file == "configfile"
             assert options.testfile == "mytestfile"
+            assert options.ignorettl == False
         monkeypatch.setattr(pydnstest.main, "main", mockreturn)
         sys.argv = ['pydnstest', '-c', 'configfile', '-f', 'mytestfile', '-V']
         x = pydnstest.main.parse_opts()
+
+    def test_options_sleep(self, monkeypatch):
+        """
+        Test the parse_opts option parsing method, with the sleep option
+        """
+        def mockreturn(options):
+            assert options.verify == True
+            assert options.config_file == "configfile"
+            assert options.testfile == "mytestfile"
+            assert options.ignorettl == False
+            assert options.sleep == 0.01
+        monkeypatch.setattr(pydnstest.main, "main", mockreturn)
+        sys.argv = ['pydnstest', '-c', 'configfile', '-f', 'mytestfile', '-V', '--sleep', '0.01']
+        x = pydnstest.main.parse_opts()
+
+    def test_options_ignorettl(self, monkeypatch):
+        """
+        Test the parse_opts option parsing method, with the ignorettl option
+        """
+        def mockreturn(options):
+            assert options.verify == True
+            assert options.config_file == "configfile"
+            assert options.testfile == "mytestfile"
+            assert options.ignorettl == True
+        monkeypatch.setattr(pydnstest.main, "main", mockreturn)
+        sys.argv = ['pydnstest', '-c', 'configfile', '-f', 'mytestfile', '-V', '--ignore-ttl']
+        x = pydnstest.main.parse_opts()
